.. toctree::
   :maxdepth: 2
   :hidden:

   self
   level_one
   specs/spec-214
   specs/spec-122
   reference
   release_history

.. _data-products:

DKIST Data Products
-------------------

This section of the DKIST documentation covers the data products generated by DKIST at all processing levels and stages.
The focus is on the level one data products, as these have been designed for consumption by scientists, the level 0 products which are available upon request have less of a focus on the end-user.

First Steps
-----------

* **From the start**: :ref:`level-one-data-products`.
* **Detailed Specifications**: :ref:`spec-214` | :ref:`spec-122`
* **Details**: :ref:`api-reference` | :ref:`release_history`.

Getting Around the Documentation
--------------------------------

The documentation is split up into sections:

* An introduction to level one data products and how these are packaged by the data center.
* A detailed specification of the level one FITS headers (known as DKIST Spec 214).
* A detailed specification of the level zero FITS headers (known as DKIST Spec 122).
